import axios from 'axios'
import { Loading } from 'element-ui'

let loadingInstance = ''
let loadingCount = 0

let resetLoading = function() {
  loadingInstance && loadingInstance.close();
  loadingInstance = ''
  loadingCount = 0
}

// serverUrl
if(!!process && !!process.env && !!process.env.GateWayServer) var serverUrl = process.env.GateWayServer
else var serverUrl = window.GateWayServer

const JSONbig = require('json-bigint-string');

axios.defaults.headers.get['Content-Type']='application/x-www-form-urlencoded';
axios.defaults.headers.post['Content-Type']='application/json';


axios.interceptors.request.use(function(config) {
  //在发送请求之前做某事
  try {
    loadingInstance = Loading.service({});
    loadingCount++
  } catch(err) {
    resetLoading()
  }
  return config;
}, function(error) {
  return Promise.reject(error);
});

axios.defaults.transformResponse =  [function (data) {
  // Do whatever you want to transform the data
  return JSONbig.parse(data);
}]


axios.interceptors.response.use(async function(response) {
  // loading处理
  try {
    loadingCount--
    if (loadingCount == 0) loadingInstance.close();
    setTimeout(function () {
      resetLoading()
    }, 5000)
  } catch(err) {
    resetLoading()
  }
  
  // Do something with response data
  if(response && process.server && response.config) { // 服务端打印日志
    console.log("=====================seperate line=====================")
    console.log("axios from server url:", response.config.url)
  }
  // 非接口类 请求，直接返回
  if(!response) response = ''
  if(!response || !response.data || !response.data.code) return response;
  
 
  let data = response.data.data || '';
  let code = response.data.code;
  
  // token超时需要重新刷新token, 600测试用
  // token超时直接退出
  if(code == 301) {
    try{
      window.location.href = "/"
    }catch(error) {
      console.log(response,error)
    }
    // if(!!Cookies) {
    //   axios.get(serverUrl+"/sso/oauth2/refresh?accessToken=" + Cookies.get("accessToken") + "&refreshToken=" +  Cookies.get("refreshToken")).then(function(res){
    //     console.log("res:", res)
  
    //     axios.get(response.config.url).then((resData) => {
    //       //更新token
    //     })
    //   })
  
    // }
  }

  if(code == 'OK' || code == 200) {
    if(process.server) { // 服务端打印日志
      console.log("response:", JSON.stringify(data))
    }
    return data;
  } else {
    console.log('axios加载失败:', response.data);
  }
  return response;
}, function(error) {
  // Do something with response error
  try {
    resetLoading()
    return Promise.reject(error);
  } catch(err) {}
});

export default axios
